@@ -1,10 +1,12 @@
+import numpy as np
 import matplotlib.pyplot as plt
 from sklearn.metrics import confusion_matrix
 from mlxtend.plotting import plot_confusion_matrix
 
-def cm(Y_true, Y_pred, output_file=None, labels=None,
+
+def calc_cm(Y_true, Y_pred, output_file=None, labels=None,
        figsize=(8.5, 7.5), colorbar=True, show_absolute=True,
-       show_normed=True, ylim=[1.5, -.5]):
+       show_normed=True, ylim=None):
     cm = confusion_matrix(Y_true, Y_pred)
     acc = np.trace(cm) / np.sum(cm).astype('float')
     loss = 1 - acc
@@ -13,6 +15,7 @@ def cm(Y_true, Y_pred, output_file=None, labels=None,
                               show_normed=show_normed, class_names=labels, figsize=figsize)
         plt.title("Confusion Matrix\nAccuracy={:0.4f}; Loss={:0.4f}".format(acc, loss))
         plt.tight_layout()
-        plt.ylim(ylim)
+        if ylim:
+            plt.ylim(ylim)
         plt.savefig(output_file)
-    return (cm, acc, loss)
\ No newline at end of file
+    return (cm, acc, loss)
